
import getopt
import sys
from fgcz import fcc

if __name__ == "__main__":
    try:
        opts, args = getopt.getopt(sys.argv[1:], "hoepl", [
                                   "help", "output=", "exec", "pattern=", "loop", "hostname=", "ncpu="])
    except getopt.GetoptError as err:
        print (str(err))
        usage()
        raise

    fcc = fcc.Fcc()

    for o, value in opts:
        if o == "--output":
            fcc.set_para('myOutputFile', value)
        elif o == "--exec":
            fcc.set_para('exec', True)
        elif o == "--loop":
            fcc.set_para('loop', True)
        elif o == "--pattern":
            fcc.set_para('myPattern', value)
        elif o == "--hostname":
            myHostname = value
        elif o == "--ncpu":
            fcc.set_para('ncpu',  int(value))
        elif o in ("--help"):
            usage()
            sys.exit(0)
        else:
            usage()
            sys.exit(1)

    crawl_pattern = ['S:', 'p[0-9]+',
                     'Proteomics',
                     '(EXTERNAL|FUSION|G2HD|GCT|ORBI|QEXACTIVE|QEXACTIVEHF|QTOF|QTRAP|T100|TOFTOF|TRIPLETOF|TSQ|VELOS)_[0-9]',
                     '[a-z]{3,18}_[0-9]{8}(_[-a-zA-Z0-9_]+){0,1}',
                     '[-a-zA-Z0-9_]+.(RAW|raw)$']

    fcc.set_para('crawl_pattern', crawl_pattern)
    fcc.set_para('max_time_diff', 60 * 60 * 24 * 7 * 10) 
    fcc.run()



#!/usr/bin/python
import os
import getopt
import sys
import tempfile

from fgcz import fcc

def create_pidfile():
    try:
        pidfile = "{0}/fcc.pid".format(tempfile.gettempdir())
        if os.path.isfile(pidfile):
            print "{0} already exists.  exit.".format(pidfile)
            sys.exit(1)
        else:
            with open(pidfile, 'w') as f:
                f.write("fcc is running")
    except: 
        print "creating {0} failed.".format(pidfile)
        sys.exit(1)

def unlink_pidfile():
    pidfile = "{0}/fcc.pid".format(tempfile.gettempdir())
    try:
        os.unlink(pidfile)
    except:
        print "removing '{0}' failed".format(pidfile)

if __name__ == "__main__":
    #create_pidfile()
    try:
        opts, args = getopt.getopt(sys.argv[1:], "hoepl", [
                                   "help", "output=", "exec", "pattern=", "loop", "hostname=", "ncpu="])
    except getopt.GetoptError as err:
        print (str(err))
        sys.exit(2)

    fcc = fcc.Fcc()

    for o, value in opts:
        if o == "--output":
            fcc.set_para('myOutputFile', value)
        elif o == "--exec":
            fcc.set_para('exec', True)
        elif o == "--loop":
            fcc.set_para('loop', True)
        elif o == "--pattern":
            fcc.set_para('myPattern', value)
        elif o == "--hostname":
            fcc.set_para('hostname', value)
        elif o == "--ncpu":
            fcc.set_para('ncpu',  int(value))
        elif o in ("--help"):
            usage()
            sys.exit(0)
        else:
            usage()
            sys.exit(1)

    crawl_pattern = ['/srv/www/htdocs/Data2San/',
        'p[0-9]{2,4}', '(Metabolomics|Proteomics)',
        '(EXTERNAL|GCT|G2HD)_[0-9]',
        '[a-z]{3,18}_[0-9]{8}(_[-a-zA-Z0-9_]{0,100}){0,1}',
        '[-a-zA-Z0-9_]+.(raw|RAW|wiff|wiff\.scan)']

    fcc.set_para('crawl_pattern', crawl_pattern)
    #fcc.set_para('max_time_diff', 60 * 60 * 24 * 7 * 10)


    fcc.run()
    #unlink_pidfile()



from setuptools import setup


"""
https://python-packaging.readthedocs.io/en/latest/command-line-scripts.html

python setup.py register sdist upload
"""


def readme():
    with open('README.rst') as f:
        return f.read()


setup(name='PyFGCZ',
      version='0.5.8',
      description="PyFGCZ contains BioBeamer and FCC python code.",
      long_description=readme(),
      classifiers=[
        'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',
        'Environment :: Console',
        'Intended Audience :: Developers',
        'Intended Audience :: System Administrators',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 2.7',
        'Topic :: Scientific/Engineering :: Bio-Informatics',
        'Topic :: Utilities',
      ],
      url='https://github.com/fgcz/PyFGCZ',
      author='Christian Panse',
      author_email='cp@fgcz.ethz.ch',
      license='GPLv3',
      packages=['fgcz'],
      install_requires=[
        'PyYAML>=3',
        'lxml>=3.4.4' ],
      scripts=[
        'fgcz/scripts/fgcz_biobeamer.py',
        'fgcz/scripts/fgcz_fcc_run_linux.py',
        'fgcz/scripts/fgcz_fcc_run_windows.py'
      ],
      zip_safe=True)




#!/usr/bin/python
# -*- coding: latin1 -*-

"""
Copyright 2006-2016 Functional Genomics Center Zurich

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
    
Author / Maintainer: Christian Panse <cp@fgcz.ethz.ch>, Witold E. Wolski <wew@fgcz.ethz.ch>
"""

from fgcz import biobeamer
import socket
import time

if __name__ == "__main__":
    configuration_url = "http://fgcz-s-021.uzh.ch/config/"
    print "hostname is {0}.".format(socket.gethostname())
    bio_beamer = biobeamer.Robocopy()
    biobeamer_xsd = "{0}/BioBeamer.xsd".format(configuration_url)
    biobeamer_xml = "{0}/BioBeamer.xml".format(configuration_url)

    bio_beamer.para_from_url(xsd=biobeamer_xsd,
                     xml=biobeamer_xml)
                     
    bio_beamer.run()
    
    time.sleep(5)
    
    BBChecker = Checker()
    BBChecker.para_from_url(xsd=biobeamer_xsd,
                            xml=biobeamer_xml)
    BBChecker.run()

    sys.stdout.write("done. exit 0\n")
    time.sleep(5)
